- rd
A Date object describing the date to be advanced to the
next business day.
- days
An optional integer offset applied to the date
- unit
An optional character value denoting a time unit, default value
is “Day”, and supported values are “Days”, “Weeks”,
“Months”, “Years”, “Hours”, “Seconds”,
“Minutes”, “Milliseconds”, “Microseconds”.
- bdc
An optional integer defining a business day convention, default
is “Following”, and supported values are
“Following”, “ModifiedFollowing”, “Preceding”,
“ModifiedPreceding”, “Unadjusted”,
“HalfMonthModifiedFollowing” and “Nearest”.
- eom
An optional boolean toggle whether end-of-month is to be respected
- xp
An optional calendar object, if missing the default instance is used